@@ -50,9 +50,9 @@ try:
 except NotImplementedError:
     n_cpu = 2
 
-def setup_logging():
+def setup_logging(debug=False):
     imposm_log = logging.getLogger('imposm')
-    imposm_log.setLevel(logging.INFO)
+    imposm_log.setLevel(logging.DEBUG if debug else logging.INFO)
 
     ch = logging.StreamHandler(sys.stdout)
     ch.setLevel(logging.DEBUG)
@@ -65,13 +65,15 @@ __version__ = imposm.version.__version__
 
 def main(argv=None):
     setproctitle('imposm: main')
-    setup_logging()
 
     usage = '%prog [options] [input]...'
     parser = optparse.OptionParser(usage=usage, add_help_option=False,
         version="%prog " + __version__)
     parser.add_option('--help', dest='help', action='store_true',
         default=False, help='show this help message and exit')
+    parser.add_option('--debug', action='store_true',
+        default=False, help='show debug information')
+    
     parser.add_option('-m', '--mapping-file', dest='mapping_file',
         metavar='<file>')
     parser.add_option('-h', '--host', dest='host', metavar='<host>')
@@ -93,7 +95,7 @@ def main(argv=None):
     
     
     parser.add_option('--table-prefix',
-        dest='table_prefix', default='osm_new_', metavar='osm_new_',
+        dest='table_prefix', default=None, metavar='osm_new_',
         help='prefix for imported tables')
     parser.add_option('--table-prefix-production',
         dest='table_prefix_production', default='osm_', metavar='osm_',
@@ -125,6 +127,8 @@ def main(argv=None):
 
     (options, args) = parser.parse_args(argv)
 
+    setup_logging(debug=options.debug)
+
     if (argv and len(argv) == 0) or len(sys.argv) == 1:
         options.help = True
 
@@ -159,6 +163,10 @@ def main(argv=None):
     if (options.write or options.optimize or options.deploy_tables
         or options.remove_backup_tables or options.recover_tables):
         db_conf = mappings['db_conf']
+        if options.table_prefix:
+            db_conf.prefix = options.table_prefix
+        else:
+            options.table_prefix = db_conf.prefix
         
         if options.connection:
             from imposm.db.config import db_conf_from_string
