@@ -67,7 +67,6 @@ class ImporterProcess(Process):
             for m in ms:
                 osm_elem = OSMElem(osm_id, geom, type, tags)
                 try:
-                    m.name_filter(osm_elem)
                     m.filter(osm_elem)
                     m.build_geom(osm_elem)
                     extra_args = m.field_values(osm_elem)
@@ -184,7 +183,7 @@ class DBImporter(threading.Thread):
 
             mapping, osm_id, osm_elem, extra_args = data
             insert_data = self.mappings[mapping]
-            insert_data.append((osm_id, osm_elem.name, osm_elem.type, self.db.geom_wrapper(osm_elem.geom)) + tuple(extra_args))
+            insert_data.append((osm_id, osm_elem.type, self.db.geom_wrapper(osm_elem.geom)) + tuple(extra_args))
 
             if len(insert_data) >= 128:
                 if not self.dry_run:
